<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Indicator</source>
        <translation>Gösterge</translation>
    </message>
</context>
</TS>